#
# spec file for package cpu-x
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_name CPU-X-%version
Name:           cpu-x
Version:        4.5.2
Release:        bp155.1.5
Summary:        Hardware overview utility
License:        GPL-3.0-or-later
Group:          System/X11/Utilities
URL:            https://github.com/TheTumultuousUnicornOfDarkness/CPU-X
Source:         https://github.com/TheTumultuousUnicornOfDarkness/CPU-X/archive/refs/tags/v%version.tar.gz
Patch1:         no-no-pie.patch
BuildRequires:  cmake
BuildRequires:  gettext-tools
%ifarch %ix86 x86_64
BuildRequires:  nasm
%endif
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(libcpuid) >= 0.6.0
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libprocps)
BuildRequires:  pkgconfig(ncursesw)
# https://github.com/TheTumultuousUnicornOfDarkness/CPU-X/issues/105
Provides:       bundled(bandwidth) = 1.5.1
Provides:       bundled(dmidecode) = 3.4.20220922.f50b925

%description
CPU-X is a software that gathers information about CPU, motherboard
and peripherals. It is similar to CPU-Z (Windows) and can be used in
graphical mode by using GTK or in text-based mode by using NCurses. A
dump mode is present from command line.

%package bash-completion
Summary:        Bash completion for %name
Group:          System/Shells
Supplements:    (%name and bash-completion)
BuildArch:      noarch

%description bash-completion
Shell completion definitions from %name for %name.

%package fish-completion
Summary:        Bash completion for %name
Group:          System/Shells
Supplements:    (%name and fish)
BuildArch:      noarch

%description fish-completion
Shell completion definitions from %name for %name.

%package zsh-completion
Summary:        Bash completion for %name
Group:          System/Shells
Supplements:    (%name and zsh)
BuildArch:      noarch

%description zsh-completion
Shell completion definitions from %name for %name.

%lang_package

%prep
%autosetup -p1 -n %src_name

%build
%cmake
%cmake_build

%install
%cmake_install
rm -Rf "%buildroot/%_datadir/polkit-1" "%buildroot/%_datadir/applications"
%find_lang %name

%files
%_bindir/cpu-x
%_libexecdir/cpu-x*
%_datadir/cpu-x/
%_datadir/icons/*
%_datadir/glib-2.0/
%_datadir/metainfo/
%license COPYING

%files bash-completion
%_datadir/bash-completion/

%files fish-completion
%_datadir/fish/

%files lang -f %name.lang

%files zsh-completion
%_datadir/zsh/

%changelog
* Thu Nov 17 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.5.2
  * Add support for hybrid CPUs
  * Add support for TAB key and scrolling in NCurses TUI
  * Support for procps-ng 4.0.1rc3
  * Update databases (Intel Tremont, Intel Ice Lake Xeon-D, AMD
    Mendocino, AMD Zen 2 Desktop Kit, AMD Athlon 64 Sherman)
* Thu Aug 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.3.1:
  * Fix CPU usage in System tab when theme is Auto
  * Fix a crash when libpci is upgraded and CPU-X is not rebuild
    against the new shared library
* Mon Apr 18 2022 Manfred Hollstein <manfred.h@gmx.net>
- Revert, see https://bugzilla.opensuse.org/show_bug.cgi?id=1198266
* Thu Apr  7 2022 Manfred Hollstein <manfred.h@gmx.net>
- Use new libproc-2 on Tumbleweed instead of libprocps.
* Sat Mar 19 2022 Matthias Fehring <buschmann23@opensuse.org>
- Add opencl-headers to the BuildRequires to fix build on
  openSUSE Leap 15.3
* Sat Mar 19 2022 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 4.3.0
  * Add Compute Unit in Graphics Tab (require OpenCL)
  * Add Resizable BAR in Graphics tab
  * Update databases
  * Rename from "Ext. Family/Model" to "Disp. Family/Model"
  * Display a warning for unsupported CPUs
  * Patch dmidecode to version 3.3.024b0fb4
  * Fix build with musl libc
  * Limit number of characters for labels in Graphics tab (GTK GUI)
  * Allow to translate settings (GTK GUI)
- Add pkgconfig(OpenCL) to the BuildRequires
* Wed Jun 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.2.0
  * Remove support for libcpuid before v0.5.0
  * Add glfw dependency for UMD
  * Add new option --cpuid-decimal to display CPUID values in decimal
  * Add User Mode Driver (UMD) to Graphics Tab
  * Add GPU DeviceID:RevisonID in Graphics tab
  * Add PCIe link speed/width in Graphics tab
  * Add CPUX_ARGS environment variable to set default command line
  * Add alternative key mapping for NCurses mode (option --keymap)
  * Add debug mode (option --debug)
  * Add screen reader accessibility on GUI
  * Add Core Voltage, Power Avg and Memory Used in Graphics tab
    (AMDGPU only)
  * Add a dropdown list in Graphics tab to choose graphic card to monitor
  * Reduce the GPU clock precision in Graphics tab
  * Update CPU databasesSupport more GPU in Graphics tab
  * Change bars color in System tab in GTK GUI when Dark theme is used
  * Ignore batteries voltage when searching CPU voltage
  * Fix for --issue-fmt
  * Fix overflow caused by some translations
  * Fix list of influenceable environment variables in help
  * Fix screen flickering in NCurses TUI
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Split language files to -lang subpackage.
* Mon Oct 12 2020 Jan Engelhardt <jengelh@inai.de>
- Make powerpc builds possible. Split shell completions.
* Sat Oct 10 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 4.0.1) for build.opensuse.org
